# Adansonia

<div align="center">
  <img src="https://upload.wikimedia.org/wikipedia/commons/thumb/c/cb/Adansonia_grandidieri03.jpg/640px-Adansonia_grandidieri03.jpg">
</div>

_Adansonia_ is a genus of deciduous trees known as baobabs. They are found in arid regions of Madagascar, mainland Africa, Arabia, and Australia. The generic name honours [Michel Adanson](https://fr.wikipedia.org/wiki/Michel_Adanson), the French naturalist and explorer who described Adansonia digitata.

| **`Documentation`**                                                                                                                      |
|------------------------------------------------------------------------------------------------------------------------------------------|
| [![Documentation](https://img.shields.io/badge/api-reference-blue.svg)](https://github.com/baobab-group/Adansonia/blob/master/README.md) |


## License

[Apache License 2.0](LICENSE)
